/// <reference types="@types/es6-shim" />
//========================================================================
// RAML-defined Typed REST Client for 'YaasApiProductV2'
//========================================================================
"use strict";
exports.__esModule = true;
var popsicle = require("popsicle");
var extend = require("deep-extend");
var rxjs_1 = require("@reactivex/rxjs");
//========================================================================
// Actions
//========================================================================
var TEMPLATE_REGEXP = /{([^{}]+)}/g;
function template(string, interpolate) {
    return string.replace(TEMPLATE_REGEXP, function (match, key) {
        if (interpolate[key] != null) {
            return encodeURIComponent(interpolate[key]);
        }
        return '';
    });
}
var YaasApiProductV2 = (function () {
    // RAML resources without parameters
    function YaasApiProductV2(options) {
        this._path = '';
        this._options = extend({
            baseUri: 'https://api.yaas.io/hybris/product/v2',
            baseUriParameters: {}
        }, options);
        //function client (method, path, options) {
        //  return this.request(client, method, path, options)
        //}
        // Initialize RAML resourcs without parameters
        this._client = this;
        this._form = popsicle.form;
        this._version = 'v2';
        this._Security = {};
        // RAML resources with parameters
    }
    YaasApiProductV2.prototype.request = function (client, method, path, opts) {
        var options = extend({}, client._options, opts);
        var baseUri = template(options.baseUri, options.baseUriParameters);
        var reqOpts = {
            url: baseUri.replace(/\/$/, '') + template(path, options.uriParameters),
            method: method,
            headers: extend(options.headers, options.getHeaders ? options.getHeaders() : {}),
            body: options.body,
            query: options.query,
            options: options.options
        };
        if (options.user && typeof options.user.sign === 'function') {
            reqOpts = options.user.sign(reqOpts);
        }
        return popsicle.request(reqOpts);
    };
    // createProtoResources - Resource: Client
    YaasApiProductV2.prototype.tenant = function (tenant) { return new Resources.Tenant(this._client, this._path + template('/{tenant}', extend({}, { tenant: tenant }))); };
    return YaasApiProductV2;
}());
exports.YaasApiProductV2 = YaasApiProductV2;
var Resources;
(function (Resources) {
    // createResource - Tenant
    var Tenant = (function () {
        function Tenant(client, path) {
            this._client = client;
            this._path = path;
            this.products = new Tenant.TenantProducts(this._client, this._path + '/products');
            this.variants = new Tenant.TenantVariants(this._client, this._path + '/variants');
            this.search = new Tenant.TenantSearch(this._client, this._path + '/search');
        }
        return Tenant;
    }());
    Resources.Tenant = Tenant;
    (function (Tenant) {
        // createResource - TenantProducts
        var TenantProducts = (function () {
            function TenantProducts(client, path) {
                this._client = client;
                this._path = path;
            }
            // createProtoResources - Resource: TenantProducts
            TenantProducts.prototype.productId = function (productId) { return new Tenant.TenantProducts.TenantProductsProductId(this._client, this._path + template('/{productId}', extend({}, { productId: productId }))); };
            /**
             * GET on TenantProducts
             */
            TenantProducts.prototype.GET = function (fields, q, sort, pageNumber, pageSize, opts) {
                var _this = this;
                return rxjs_1.Observable.create(function (observer) {
                    var options = extend({ query: {}, headers: {} }, opts);
                    if (fields !== undefined && fields !== null)
                        options.query['fields'] = fields;
                    if (q !== undefined && q !== null)
                        options.query['q'] = q;
                    if (sort !== undefined && sort !== null)
                        options.query['sort'] = sort;
                    if (pageNumber !== undefined && pageNumber < 1) {
                        observer.error('Parameter \'pageNumber\' outside specified range!');
                        return;
                    }
                    if (pageNumber !== undefined && pageNumber !== null)
                        options.query['pageNumber'] = pageNumber;
                    if (pageSize !== undefined && pageSize < 1) {
                        observer.error('Parameter \'pageSize\' outside specified range!');
                        return;
                    }
                    if (pageSize !== undefined && pageSize !== null)
                        options.query['pageSize'] = pageSize;
                    _this._client.request(_this._client, 'get', _this._path, options)
                        .use(popsicle.plugins.parse('json'))
                        .then(function (response) {
                        var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                        r["_" + response.status] = response.body;
                        observer.next(r);
                        observer.complete();
                    });
                });
            };
            /**
             * POST on TenantProducts
             */
            TenantProducts.prototype.POST = function (body /* Implicitly defined schemas not yet supported */, opts) {
                var _this = this;
                return rxjs_1.Observable.create(function (observer) {
                    var options = extend({ query: {}, headers: {} }, opts);
                    options.body = body;
                    _this._client.request(_this._client, 'post', _this._path, options)
                        .use(popsicle.plugins.parse('json'))
                        .then(function (response) {
                        var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                        r["_" + response.status] = response.body;
                        observer.next(r);
                        observer.complete();
                    });
                });
            };
            /**
             * DELETE on TenantProducts
             */
            TenantProducts.prototype.DELETE = function (opts) {
                var _this = this;
                return rxjs_1.Observable.create(function (observer) {
                    var options = extend({ query: {}, headers: {} }, opts);
                    _this._client.request(_this._client, 'delete', _this._path, options)
                        .use(popsicle.plugins.parse('json'))
                        .then(function (response) {
                        var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                        r["_" + response.status] = response.body;
                        observer.next(r);
                        observer.complete();
                    });
                });
            };
            return TenantProducts;
        }());
        Tenant.TenantProducts = TenantProducts;
        (function (TenantProducts) {
            // createResource - TenantProductsProductId
            var TenantProductsProductId = (function () {
                function TenantProductsProductId(client, path) {
                    this._client = client;
                    this._path = path;
                    this.media = new Tenant.TenantProducts.TenantProductsProductId.TenantProductsProductIdMedia(this._client, this._path + '/media');
                    this.variants = new Tenant.TenantProducts.TenantProductsProductId.TenantProductsProductIdVariants(this._client, this._path + '/variants');
                }
                /**
                 * GET on TenantProductsProductId
                 */
                TenantProductsProductId.prototype.GET = function (fields, opts) {
                    var _this = this;
                    return rxjs_1.Observable.create(function (observer) {
                        var options = extend({ query: {}, headers: {} }, opts);
                        if (fields !== undefined && fields !== null)
                            options.query['fields'] = fields;
                        _this._client.request(_this._client, 'get', _this._path, options)
                            .use(popsicle.plugins.parse('json'))
                            .then(function (response) {
                            var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                            r["_" + response.status] = response.body;
                            observer.next(r);
                            observer.complete();
                        });
                    });
                };
                /**
                 * PUT on TenantProductsProductId
                 */
                TenantProductsProductId.prototype.PUT = function (body /* Implicitly defined schemas not yet supported */, partial, opts) {
                    var _this = this;
                    return rxjs_1.Observable.create(function (observer) {
                        var options = extend({ query: {}, headers: {} }, opts);
                        if (partial !== undefined && partial !== null)
                            options.query['partial'] = partial;
                        options.body = body;
                        _this._client.request(_this._client, 'put', _this._path, options)
                            .use(popsicle.plugins.parse('json'))
                            .then(function (response) {
                            var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                            r["_" + response.status] = response.body;
                            observer.next(r);
                            observer.complete();
                        });
                    });
                };
                /**
                 * DELETE on TenantProductsProductId
                 */
                TenantProductsProductId.prototype.DELETE = function (opts) {
                    var _this = this;
                    return rxjs_1.Observable.create(function (observer) {
                        var options = extend({ query: {}, headers: {} }, opts);
                        _this._client.request(_this._client, 'delete', _this._path, options)
                            .use(popsicle.plugins.parse('json'))
                            .then(function (response) {
                            var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                            r["_" + response.status] = response.body;
                            observer.next(r);
                            observer.complete();
                        });
                    });
                };
                return TenantProductsProductId;
            }());
            TenantProducts.TenantProductsProductId = TenantProductsProductId;
            (function (TenantProductsProductId) {
                // createResource - TenantProductsProductIdMedia
                var TenantProductsProductIdMedia = (function () {
                    function TenantProductsProductIdMedia(client, path) {
                        this._client = client;
                        this._path = path;
                    }
                    // createProtoResources - Resource: TenantProductsProductIdMedia
                    TenantProductsProductIdMedia.prototype.mediaId = function (mediaId) { return new Tenant.TenantProducts.TenantProductsProductId.TenantProductsProductIdMedia.TenantProductsProductIdMediaMediaId(this._client, this._path + template('/{mediaId}', extend({}, { mediaId: mediaId }))); };
                    /**
                     * POST on TenantProductsProductIdMedia
                     */
                    TenantProductsProductIdMedia.prototype.POST = function (body /* Implicitly defined schemas not yet supported */, opts) {
                        var _this = this;
                        return rxjs_1.Observable.create(function (observer) {
                            var options = extend({ query: {}, headers: {} }, opts);
                            options.body = body;
                            _this._client.request(_this._client, 'post', _this._path, options)
                                .use(popsicle.plugins.parse('json'))
                                .then(function (response) {
                                var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                                r["_" + response.status] = response.body;
                                observer.next(r);
                                observer.complete();
                            });
                        });
                    };
                    /**
                     * GET on TenantProductsProductIdMedia
                     */
                    TenantProductsProductIdMedia.prototype.GET = function (opts) {
                        var _this = this;
                        return rxjs_1.Observable.create(function (observer) {
                            var options = extend({ query: {}, headers: {} }, opts);
                            _this._client.request(_this._client, 'get', _this._path, options)
                                .use(popsicle.plugins.parse('json'))
                                .then(function (response) {
                                var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                                r["_" + response.status] = response.body;
                                observer.next(r);
                                observer.complete();
                            });
                        });
                    };
                    return TenantProductsProductIdMedia;
                }());
                TenantProductsProductId.TenantProductsProductIdMedia = TenantProductsProductIdMedia;
                (function (TenantProductsProductIdMedia) {
                    // createResource - TenantProductsProductIdMediaMediaId
                    var TenantProductsProductIdMediaMediaId = (function () {
                        function TenantProductsProductIdMediaMediaId(client, path) {
                            this._client = client;
                            this._path = path;
                            this.commit = new Tenant.TenantProducts.TenantProductsProductId.TenantProductsProductIdMedia.TenantProductsProductIdMediaMediaId.TenantProductsProductIdMediaMediaIdCommit(this._client, this._path + '/commit');
                        }
                        /**
                         * GET on TenantProductsProductIdMediaMediaId
                         */
                        TenantProductsProductIdMediaMediaId.prototype.GET = function (opts) {
                            var _this = this;
                            return rxjs_1.Observable.create(function (observer) {
                                var options = extend({ query: {}, headers: {} }, opts);
                                _this._client.request(_this._client, 'get', _this._path, options)
                                    .use(popsicle.plugins.parse('json'))
                                    .then(function (response) {
                                    var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                                    r["_" + response.status] = response.body;
                                    observer.next(r);
                                    observer.complete();
                                });
                            });
                        };
                        /**
                         * PUT on TenantProductsProductIdMediaMediaId
                         */
                        TenantProductsProductIdMediaMediaId.prototype.PUT = function (body /* Implicitly defined schemas not yet supported */, partial, opts) {
                            var _this = this;
                            return rxjs_1.Observable.create(function (observer) {
                                var options = extend({ query: {}, headers: {} }, opts);
                                if (partial !== undefined && partial !== null)
                                    options.query['partial'] = partial;
                                options.body = body;
                                _this._client.request(_this._client, 'put', _this._path, options)
                                    .use(popsicle.plugins.parse('json'))
                                    .then(function (response) {
                                    var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                                    r["_" + response.status] = response.body;
                                    observer.next(r);
                                    observer.complete();
                                });
                            });
                        };
                        /**
                         * DELETE on TenantProductsProductIdMediaMediaId
                         */
                        TenantProductsProductIdMediaMediaId.prototype.DELETE = function (opts) {
                            var _this = this;
                            return rxjs_1.Observable.create(function (observer) {
                                var options = extend({ query: {}, headers: {} }, opts);
                                _this._client.request(_this._client, 'delete', _this._path, options)
                                    .use(popsicle.plugins.parse('json'))
                                    .then(function (response) {
                                    var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                                    r["_" + response.status] = response.body;
                                    observer.next(r);
                                    observer.complete();
                                });
                            });
                        };
                        return TenantProductsProductIdMediaMediaId;
                    }());
                    TenantProductsProductIdMedia.TenantProductsProductIdMediaMediaId = TenantProductsProductIdMediaMediaId;
                    (function (TenantProductsProductIdMediaMediaId) {
                        // createResource - TenantProductsProductIdMediaMediaIdCommit
                        var TenantProductsProductIdMediaMediaIdCommit = (function () {
                            function TenantProductsProductIdMediaMediaIdCommit(client, path) {
                                this._client = client;
                                this._path = path;
                            }
                            /**
                             * POST on TenantProductsProductIdMediaMediaIdCommit
                             */
                            TenantProductsProductIdMediaMediaIdCommit.prototype.POST = function (opts) {
                                var _this = this;
                                return rxjs_1.Observable.create(function (observer) {
                                    var options = extend({ query: {}, headers: {} }, opts);
                                    _this._client.request(_this._client, 'post', _this._path, options)
                                        .use(popsicle.plugins.parse('json'))
                                        .then(function (response) {
                                        var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                                        r["_" + response.status] = response.body;
                                        observer.next(r);
                                        observer.complete();
                                    });
                                });
                            };
                            return TenantProductsProductIdMediaMediaIdCommit;
                        }());
                        TenantProductsProductIdMediaMediaId.TenantProductsProductIdMediaMediaIdCommit = TenantProductsProductIdMediaMediaIdCommit;
                    })(TenantProductsProductIdMediaMediaId = TenantProductsProductIdMedia.TenantProductsProductIdMediaMediaId || (TenantProductsProductIdMedia.TenantProductsProductIdMediaMediaId = {}));
                })(TenantProductsProductIdMedia = TenantProductsProductId.TenantProductsProductIdMedia || (TenantProductsProductId.TenantProductsProductIdMedia = {}));
                // createResource - TenantProductsProductIdVariants
                var TenantProductsProductIdVariants = (function () {
                    function TenantProductsProductIdVariants(client, path) {
                        this._client = client;
                        this._path = path;
                    }
                    // createProtoResources - Resource: TenantProductsProductIdVariants
                    TenantProductsProductIdVariants.prototype.variantId = function (variantId) { return new Tenant.TenantProducts.TenantProductsProductId.TenantProductsProductIdVariants.TenantProductsProductIdVariantsVariantId(this._client, this._path + template('/{variantId}', extend({}, { variantId: variantId }))); };
                    /**
                     * GET on TenantProductsProductIdVariants
                     */
                    TenantProductsProductIdVariants.prototype.GET = function (fields, q, pageNumber, pageSize, opts) {
                        var _this = this;
                        return rxjs_1.Observable.create(function (observer) {
                            var options = extend({ query: {}, headers: {} }, opts);
                            if (fields !== undefined && fields !== null)
                                options.query['fields'] = fields;
                            if (q !== undefined && q !== null)
                                options.query['q'] = q;
                            if (pageNumber !== undefined && pageNumber < 1) {
                                observer.error('Parameter \'pageNumber\' outside specified range!');
                                return;
                            }
                            if (pageNumber !== undefined && pageNumber !== null)
                                options.query['pageNumber'] = pageNumber;
                            if (pageSize !== undefined && pageSize < 1) {
                                observer.error('Parameter \'pageSize\' outside specified range!');
                                return;
                            }
                            if (pageSize !== undefined && pageSize !== null)
                                options.query['pageSize'] = pageSize;
                            _this._client.request(_this._client, 'get', _this._path, options)
                                .use(popsicle.plugins.parse('json'))
                                .then(function (response) {
                                var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                                r["_" + response.status] = response.body;
                                observer.next(r);
                                observer.complete();
                            });
                        });
                    };
                    /**
                     * POST on TenantProductsProductIdVariants
                     */
                    TenantProductsProductIdVariants.prototype.POST = function (body /* Implicitly defined schemas not yet supported */, opts) {
                        var _this = this;
                        return rxjs_1.Observable.create(function (observer) {
                            var options = extend({ query: {}, headers: {} }, opts);
                            options.body = body;
                            _this._client.request(_this._client, 'post', _this._path, options)
                                .use(popsicle.plugins.parse('json'))
                                .then(function (response) {
                                var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                                r["_" + response.status] = response.body;
                                observer.next(r);
                                observer.complete();
                            });
                        });
                    };
                    /**
                     * DELETE on TenantProductsProductIdVariants
                     */
                    TenantProductsProductIdVariants.prototype.DELETE = function (opts) {
                        var _this = this;
                        return rxjs_1.Observable.create(function (observer) {
                            var options = extend({ query: {}, headers: {} }, opts);
                            _this._client.request(_this._client, 'delete', _this._path, options)
                                .use(popsicle.plugins.parse('json'))
                                .then(function (response) {
                                var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                                r["_" + response.status] = response.body;
                                observer.next(r);
                                observer.complete();
                            });
                        });
                    };
                    return TenantProductsProductIdVariants;
                }());
                TenantProductsProductId.TenantProductsProductIdVariants = TenantProductsProductIdVariants;
                (function (TenantProductsProductIdVariants) {
                    // createResource - TenantProductsProductIdVariantsVariantId
                    var TenantProductsProductIdVariantsVariantId = (function () {
                        function TenantProductsProductIdVariantsVariantId(client, path) {
                            this._client = client;
                            this._path = path;
                            this.media = new Tenant.TenantProducts.TenantProductsProductId.TenantProductsProductIdVariants.TenantProductsProductIdVariantsVariantId.TenantProductsProductIdVariantsVariantIdMedia(this._client, this._path + '/media');
                        }
                        /**
                         * GET on TenantProductsProductIdVariantsVariantId
                         */
                        TenantProductsProductIdVariantsVariantId.prototype.GET = function (opts) {
                            var _this = this;
                            return rxjs_1.Observable.create(function (observer) {
                                var options = extend({ query: {}, headers: {} }, opts);
                                _this._client.request(_this._client, 'get', _this._path, options)
                                    .use(popsicle.plugins.parse('json'))
                                    .then(function (response) {
                                    var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                                    r["_" + response.status] = response.body;
                                    observer.next(r);
                                    observer.complete();
                                });
                            });
                        };
                        /**
                         * PUT on TenantProductsProductIdVariantsVariantId
                         */
                        TenantProductsProductIdVariantsVariantId.prototype.PUT = function (body /* Implicitly defined schemas not yet supported */, opts) {
                            var _this = this;
                            return rxjs_1.Observable.create(function (observer) {
                                var options = extend({ query: {}, headers: {} }, opts);
                                options.body = body;
                                _this._client.request(_this._client, 'put', _this._path, options)
                                    .use(popsicle.plugins.parse('json'))
                                    .then(function (response) {
                                    var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                                    r["_" + response.status] = response.body;
                                    observer.next(r);
                                    observer.complete();
                                });
                            });
                        };
                        /**
                         * DELETE on TenantProductsProductIdVariantsVariantId
                         */
                        TenantProductsProductIdVariantsVariantId.prototype.DELETE = function (opts) {
                            var _this = this;
                            return rxjs_1.Observable.create(function (observer) {
                                var options = extend({ query: {}, headers: {} }, opts);
                                _this._client.request(_this._client, 'delete', _this._path, options)
                                    .use(popsicle.plugins.parse('json'))
                                    .then(function (response) {
                                    var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                                    r["_" + response.status] = response.body;
                                    observer.next(r);
                                    observer.complete();
                                });
                            });
                        };
                        return TenantProductsProductIdVariantsVariantId;
                    }());
                    TenantProductsProductIdVariants.TenantProductsProductIdVariantsVariantId = TenantProductsProductIdVariantsVariantId;
                    (function (TenantProductsProductIdVariantsVariantId) {
                        // createResource - TenantProductsProductIdVariantsVariantIdMedia
                        var TenantProductsProductIdVariantsVariantIdMedia = (function () {
                            function TenantProductsProductIdVariantsVariantIdMedia(client, path) {
                                this._client = client;
                                this._path = path;
                            }
                            // createProtoResources - Resource: TenantProductsProductIdVariantsVariantIdMedia
                            TenantProductsProductIdVariantsVariantIdMedia.prototype.mediaId = function (mediaId) { return new Tenant.TenantProducts.TenantProductsProductId.TenantProductsProductIdVariants.TenantProductsProductIdVariantsVariantId.TenantProductsProductIdVariantsVariantIdMedia.TenantProductsProductIdVariantsVariantIdMediaMediaId(this._client, this._path + template('/{mediaId}', extend({}, { mediaId: mediaId }))); };
                            /**
                             * POST on TenantProductsProductIdVariantsVariantIdMedia
                             */
                            TenantProductsProductIdVariantsVariantIdMedia.prototype.POST = function (body /* Implicitly defined schemas not yet supported */, opts) {
                                var _this = this;
                                return rxjs_1.Observable.create(function (observer) {
                                    var options = extend({ query: {}, headers: {} }, opts);
                                    options.body = body;
                                    _this._client.request(_this._client, 'post', _this._path, options)
                                        .use(popsicle.plugins.parse('json'))
                                        .then(function (response) {
                                        var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                                        r["_" + response.status] = response.body;
                                        observer.next(r);
                                        observer.complete();
                                    });
                                });
                            };
                            /**
                             * GET on TenantProductsProductIdVariantsVariantIdMedia
                             */
                            TenantProductsProductIdVariantsVariantIdMedia.prototype.GET = function (opts) {
                                var _this = this;
                                return rxjs_1.Observable.create(function (observer) {
                                    var options = extend({ query: {}, headers: {} }, opts);
                                    _this._client.request(_this._client, 'get', _this._path, options)
                                        .use(popsicle.plugins.parse('json'))
                                        .then(function (response) {
                                        var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                                        r["_" + response.status] = response.body;
                                        observer.next(r);
                                        observer.complete();
                                    });
                                });
                            };
                            return TenantProductsProductIdVariantsVariantIdMedia;
                        }());
                        TenantProductsProductIdVariantsVariantId.TenantProductsProductIdVariantsVariantIdMedia = TenantProductsProductIdVariantsVariantIdMedia;
                        (function (TenantProductsProductIdVariantsVariantIdMedia) {
                            // createResource - TenantProductsProductIdVariantsVariantIdMediaMediaId
                            var TenantProductsProductIdVariantsVariantIdMediaMediaId = (function () {
                                function TenantProductsProductIdVariantsVariantIdMediaMediaId(client, path) {
                                    this._client = client;
                                    this._path = path;
                                    this.commit = new Tenant.TenantProducts.TenantProductsProductId.TenantProductsProductIdVariants.TenantProductsProductIdVariantsVariantId.TenantProductsProductIdVariantsVariantIdMedia.TenantProductsProductIdVariantsVariantIdMediaMediaId.TenantProductsProductIdVariantsVariantIdMediaMediaIdCommit(this._client, this._path + '/commit');
                                }
                                /**
                                 * GET on TenantProductsProductIdVariantsVariantIdMediaMediaId
                                 */
                                TenantProductsProductIdVariantsVariantIdMediaMediaId.prototype.GET = function (opts) {
                                    var _this = this;
                                    return rxjs_1.Observable.create(function (observer) {
                                        var options = extend({ query: {}, headers: {} }, opts);
                                        _this._client.request(_this._client, 'get', _this._path, options)
                                            .use(popsicle.plugins.parse('json'))
                                            .then(function (response) {
                                            var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                                            r["_" + response.status] = response.body;
                                            observer.next(r);
                                            observer.complete();
                                        });
                                    });
                                };
                                /**
                                 * PUT on TenantProductsProductIdVariantsVariantIdMediaMediaId
                                 */
                                TenantProductsProductIdVariantsVariantIdMediaMediaId.prototype.PUT = function (body /* Implicitly defined schemas not yet supported */, partial, opts) {
                                    var _this = this;
                                    return rxjs_1.Observable.create(function (observer) {
                                        var options = extend({ query: {}, headers: {} }, opts);
                                        if (partial !== undefined && partial !== null)
                                            options.query['partial'] = partial;
                                        options.body = body;
                                        _this._client.request(_this._client, 'put', _this._path, options)
                                            .use(popsicle.plugins.parse('json'))
                                            .then(function (response) {
                                            var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                                            r["_" + response.status] = response.body;
                                            observer.next(r);
                                            observer.complete();
                                        });
                                    });
                                };
                                /**
                                 * DELETE on TenantProductsProductIdVariantsVariantIdMediaMediaId
                                 */
                                TenantProductsProductIdVariantsVariantIdMediaMediaId.prototype.DELETE = function (opts) {
                                    var _this = this;
                                    return rxjs_1.Observable.create(function (observer) {
                                        var options = extend({ query: {}, headers: {} }, opts);
                                        _this._client.request(_this._client, 'delete', _this._path, options)
                                            .use(popsicle.plugins.parse('json'))
                                            .then(function (response) {
                                            var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                                            r["_" + response.status] = response.body;
                                            observer.next(r);
                                            observer.complete();
                                        });
                                    });
                                };
                                return TenantProductsProductIdVariantsVariantIdMediaMediaId;
                            }());
                            TenantProductsProductIdVariantsVariantIdMedia.TenantProductsProductIdVariantsVariantIdMediaMediaId = TenantProductsProductIdVariantsVariantIdMediaMediaId;
                            (function (TenantProductsProductIdVariantsVariantIdMediaMediaId) {
                                // createResource - TenantProductsProductIdVariantsVariantIdMediaMediaIdCommit
                                var TenantProductsProductIdVariantsVariantIdMediaMediaIdCommit = (function () {
                                    function TenantProductsProductIdVariantsVariantIdMediaMediaIdCommit(client, path) {
                                        this._client = client;
                                        this._path = path;
                                    }
                                    /**
                                     * POST on TenantProductsProductIdVariantsVariantIdMediaMediaIdCommit
                                     */
                                    TenantProductsProductIdVariantsVariantIdMediaMediaIdCommit.prototype.POST = function (opts) {
                                        var _this = this;
                                        return rxjs_1.Observable.create(function (observer) {
                                            var options = extend({ query: {}, headers: {} }, opts);
                                            _this._client.request(_this._client, 'post', _this._path, options)
                                                .use(popsicle.plugins.parse('json'))
                                                .then(function (response) {
                                                var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                                                r["_" + response.status] = response.body;
                                                observer.next(r);
                                                observer.complete();
                                            });
                                        });
                                    };
                                    return TenantProductsProductIdVariantsVariantIdMediaMediaIdCommit;
                                }());
                                TenantProductsProductIdVariantsVariantIdMediaMediaId.TenantProductsProductIdVariantsVariantIdMediaMediaIdCommit = TenantProductsProductIdVariantsVariantIdMediaMediaIdCommit;
                            })(TenantProductsProductIdVariantsVariantIdMediaMediaId = TenantProductsProductIdVariantsVariantIdMedia.TenantProductsProductIdVariantsVariantIdMediaMediaId || (TenantProductsProductIdVariantsVariantIdMedia.TenantProductsProductIdVariantsVariantIdMediaMediaId = {}));
                        })(TenantProductsProductIdVariantsVariantIdMedia = TenantProductsProductIdVariantsVariantId.TenantProductsProductIdVariantsVariantIdMedia || (TenantProductsProductIdVariantsVariantId.TenantProductsProductIdVariantsVariantIdMedia = {}));
                    })(TenantProductsProductIdVariantsVariantId = TenantProductsProductIdVariants.TenantProductsProductIdVariantsVariantId || (TenantProductsProductIdVariants.TenantProductsProductIdVariantsVariantId = {}));
                })(TenantProductsProductIdVariants = TenantProductsProductId.TenantProductsProductIdVariants || (TenantProductsProductId.TenantProductsProductIdVariants = {}));
            })(TenantProductsProductId = TenantProducts.TenantProductsProductId || (TenantProducts.TenantProductsProductId = {}));
        })(TenantProducts = Tenant.TenantProducts || (Tenant.TenantProducts = {}));
        // createResource - TenantVariants
        var TenantVariants = (function () {
            function TenantVariants(client, path) {
                this._client = client;
                this._path = path;
            }
            /**
             * GET on TenantVariants
             */
            TenantVariants.prototype.GET = function (fields, id, code, expand, opts) {
                var _this = this;
                return rxjs_1.Observable.create(function (observer) {
                    var options = extend({ query: {}, headers: {} }, opts);
                    if (fields !== undefined && fields !== null)
                        options.query['fields'] = fields;
                    if (id !== undefined && id !== null)
                        options.query['id'] = id;
                    if (code !== undefined && code !== null)
                        options.query['code'] = code;
                    if (expand !== undefined && expand !== null)
                        options.query['expand'] = expand;
                    _this._client.request(_this._client, 'get', _this._path, options)
                        .use(popsicle.plugins.parse('json'))
                        .then(function (response) {
                        var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                        r["_" + response.status] = response.body;
                        observer.next(r);
                        observer.complete();
                    });
                });
            };
            return TenantVariants;
        }());
        Tenant.TenantVariants = TenantVariants;
        // createResource - TenantSearch
        var TenantSearch = (function () {
            function TenantSearch(client, path) {
                this._client = client;
                this._path = path;
            }
            /**
             * POST on TenantSearch
             */
            TenantSearch.prototype.POST = function (body /* Implicitly defined schemas not yet supported */, opts) {
                var _this = this;
                return rxjs_1.Observable.create(function (observer) {
                    var options = extend({ query: {}, headers: {} }, opts);
                    options.body = body;
                    _this._client.request(_this._client, 'post', _this._path, options)
                        .use(popsicle.plugins.parse('json'))
                        .then(function (response) {
                        var r = { headers: response.headers, responseCode: response.status, bodyRaw: response.body };
                        r["_" + response.status] = response.body;
                        observer.next(r);
                        observer.complete();
                    });
                });
            };
            return TenantSearch;
        }());
        Tenant.TenantSearch = TenantSearch;
    })(Tenant = Resources.Tenant || (Resources.Tenant = {}));
})(Resources = exports.Resources || (exports.Resources = {}));
